# -*- coding: utf-8 -*-
import json
from os import environ
from os.path import exists

import pytest

from pyscaffold.api import create_project

pytestmark = [pytest.mark.slow, pytest.mark.system]


@pytest.fixture(autouse=True)
def dont_load_dotenv():
    """pytest-virtualenv creates a `.env` directory by default, but `.env`
    entries in the file system are loaded by Pipenv as dotenv files.

    To prevent errors for happening we have to disable this feature.

    Additionally, it seems that env vars have to be changed before using
    venv, so an autouse fixture is required (cannot put this part in the
    beginning of the test function.
    """
    environ['PIPENV_DONT_LOAD_ENV'] = '1'


@pytest.fixture(autouse=True)
def cwd(tmpdir):
    """Guarantee a blank folder as workspace"""

    with tmpdir.as_cwd():
        yield tmpdir


def test_pipenv_works_with_pyscaffold(cwd, venv_path, venv_run):
    # Given a project is create with pyscaffold
    # and it have some dependencies in setup.cfg
    create_project(project='myproj', requirements=['appdirs'])
    with cwd.join('myproj').as_cwd():
        # TODO: Remove workaround https://github.com/pypa/pipenv/issues/2924
        venv_run('pip install -U pip==18.0')
        # When we install pipenv,
        venv_run('pip install -v pipenv')
        # use it to proxy setup.cfg
        venv_run('pipenv install -e .')
        # and install things to the dev env,
        venv_run('pipenv install --dev flake8')

        # Then it should be able to generate a Pipfile.lock
        venv_run('pipenv lock')
        assert exists('Pipfile.lock')

        # with the correct dependencies
        with open('Pipfile.lock') as fp:
            content = json.load(fp)
            assert content['default']['appdirs']
            assert content['develop']['flake8']

        # and run things from inside pipenv's venv
        assert venv_path in venv_run('pipenv run which flake8')
        venv_run('pipenv run flake8 src/myproj/skeleton.py')
